@@ -1,10 +1,12 @@
 # coding: utf-8
 """String utilities for creating unittest files from spec files"""
-import imp
+import os
+import sys
+import uuid
 
 
-VALID_IDENTIFIER = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" \
-    "12345678990_"
+VALID_IDENTIFIER = ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
+                    "12345678990_")
 
 
 def _camel_safe(name):
@@ -27,10 +29,15 @@ def snakify(words):
     return "_".join(identifier_safe(w) for w in words.lower().split())
 
 
-def create_module_from_string(module_name, string):
+def create_module_from_file(filepath):
     """Execute string as if it were a module, and return that module"""
-    module = imp.new_module(module_name)
-    exec string in module.__dict__
-    return module
+    name = os.path.splitext(os.path.basename(filepath))[0]
+    directory = os.path.dirname(filepath)
+    if directory not in sys.path:
+        sys.path.insert(0, directory)
+    return __import__(name)
 
 
+def uuid_hex(length=6):
+    return "_x" + uuid.uuid4().hex[:length]
+
